@@ -1,4 +1,6 @@
 import requests
+
+from .event import AppEvent
 from .auth import AppAuth
 
 class App:
@@ -7,12 +9,14 @@ class App:
             secret_key: str,
             plugin_id: str,
             auth_url = "https://auth.pluginlab.ai",
-            auth_cert_url = "https://auth.pluginlab.ai/admin/v1/cert"
+            auth_cert_url = "https://auth.pluginlab.ai/admin/v1/cert",
+            event_url = "https://event.pluginlab.ai"
         ):
         self.plugin_id = plugin_id
         self.secret_key = secret_key
         self.auth_url = auth_url
         self.auth_cert_url = auth_cert_url
+        self.event_url = event_url
 
         s = requests.Session()
         s.headers.update({
@@ -30,3 +34,13 @@ class App:
                 )
 
         return auth
+
+    def get_event(self) -> AppEvent:
+        event = AppEvent(
+                plugin_id=self.plugin_id,
+                secret_key=self.secret_key,
+                event_url=self.event_url,
+        )
+
+        return event
+        
